package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````@"````````!``````````%BQ````
M`````````$``.``)`$``'``;``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````<`````````!P``````````0`````````!````
M!0```````````````````````````````````)B=````````F)T`````````
M`"````````$````&````8*L```````!@JR```````&"K(```````P`0`````
M``!(%0``````````(````````@````8```"(JP```````(BK(```````B*L@
M``````!``@```````$`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````J)8```````"HE@```````*B6````````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````&"K````````8*L@``````!@JR``
M`````*`$````````H`0````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````,````"``````````0`
M```4`````P```$=.50`.=`$ZSKCE?O>;$:I#4U"M%,<!1A$```!$````!```
M``@````@'!``!4`$AB@"0`"0A@"`@BD`($D@!`FXHAA-N@0&"@````!$````
M2````$P```!-````5````%4```!7````6P```%P`````````7@```&$```!B
M````8P``````````````;L7?'^K3[P[.WD<M:W^:?"[%F[8@_^0.N(WQ#M5D
MU'S9<5@<XD?&`:Q+X\#RV],=NN.2?,+E/RSZH6Q@LP&+;VL)0]9FK\QFQ;F<
M0$)%U>S$B060B`=PTSGRBQP-%.*>VLWCGC-BV^T,.I<+5J2;EJ?=HVM_J9R;
MX:<""@J*$%>CX/M)````````````````````````````````$0$``!(`````
M````````````````````_`$``!(`````````````````````````<@(``!(`
M````````````````````````4`(``!(`````````````````````````$0``
M`"``````````````````````````>0(``!(`````````````````````````
M!0,``!(`````````````````````````M````!(`````````````````````
M````C@(``!(`````````````````````````@P$``!(`````````````````
M````````[0(``!(`````````````````````````Y0(``!(`````````````
M````````````A````!(`````````````````````````U`,``!(`````````
M````````````````#`$``!(`````````````````````````L0(``!(`````
M````````````````````HP(``!(`````````````````````````80(``!(`
M````````````````````````_@(``!(`````````````````````````&P,`
M`!(`````````````````````````9P$``!(`````````````````````````
M-0$``!(`````````````````````````P@```!(`````````````````````
M````L0$``!(`````````````````````````*0(``!(`````````````````
M````````6`(``!(`````````````````````````.0(``!(`````````````
M````````````G@$``!(`````````````````````````AP(``!(`````````
M````````````````]P$``!(`````````````````````````7P,``!(`````
M````````````````````6`,``!(`````````````````````````0P$``!(`
M````````````````````````#@,``!(`````````````````````````+0``
M`"``````````````````````````Q0(``!(`````````````````````````
M9````!(`````````````````````````%0(``!(`````````````````````
M````J@$``!(`````````````````````````DP```!(`````````````````
M````````GP```!(`````````````````````````7`$``!(`````````````
M````````````(@$``!(`````````````````````````5@```!(`````````
M````````````````%@$``!(`````````````````````````S`(``!(`````
M````````````````````DP$``!(`````````````````````````\````!(`
M````````````````````````?P(``!(`````````````````````````\`$`
M`!(`````````````````````````20,``!(`````````````````````````
M(@,``!(`````````````````````````=0$``!(`````````````````````
M````<P```!(`````````````````````````40,``!(`````````````````
M````````G`(``!(`````````````````````````U````!(`````````````
M````````````4P$``!(`````````````````````````V@(``!(`````````
M````````````````2P(``!(`````````````````````````#0(``!(`````
M````````````````````MP(``!(`````````````````````````/````"``
M````````````````````````E0(``!(`````````````````````````+`,`
M`"(`````````````````````````J@(``!(`````````````````````````
M.P,``!(`````````````````````````W0,``!(`#@!05@```````'``````
M````JP,``!(`#P!$5P```````````````````@0``!(`#@!`1@```````!0,
M````````;`,``!(`#@!0'@```````"T"````````L0,``!(`#@"@/P``````
M``4`````````<`0``!(`#@"P/P```````/H!````````:@0``!(`"P!@&@``
M````````````````G00``!(`#@!@4@```````.T#````````D`,``!``&0`@
ML"``````````````````Z0,``!(`#@"P00```````"H`````````'`0``!$`
M$`!05P````````0`````````O`$``!$`%0!PJR```````!,`````````G`,`
M`!``&0"HP"``````````````````:`0``!(`#@!0/@```````#``````````
M?00``!(`#@!@10```````-P`````````CP0``!(`#@"P1````````'0`````
M````#P0``!``&```L"``````````````````]@,``!(`#@#@00```````.P`
M````````<0,``!$`&0!(L"````````@`````````B0,``!``&``@L"``````
M````````````<@,``"$`&0!(L"````````@`````````400``!$`&``8L"``
M``````@`````````]P(``!$`&0!@L"````````@`````````H0,``!(`#@!`
M5P````````(`````````000``!(`#@#05@```````&4`````````%00``!(`
M#@"`(````````"L`````````$00``"``&```L"```````````````````0$`
M`!$`&0`@L"````````0`````````<P,``"$`&0!(L"````````@`````````
MP@,``!(`#@`P10```````"0`````````*P0``!(`#@#0/@```````,$`````
M````XP```!$`&0!`L"````````$`````````6P0``!(`#@#00@```````-L!
M`````````&QI8G!E<FPN<V\N-2XR-@!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7U]G;6]N7W-T87)T7U\`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO
M8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O
M;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V
M7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?
M:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`
M4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M4$Q?;65M;W)Y7W=R87``;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A
M9"YS;RXP`&]P96XV-`!R96%D`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!P
M=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&QI8F,N<V\N-@!?7W)E9VES=&5R
M7V%T9F]R:P!E>&ET`'-T<FYC;7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I
M;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<F1U<`!S
M=')T;VL`<W1R;&5N`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P
M>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`
M<W1D97)R`&=E='5I9`!R96%D;&EN:P!?7VUE;6-P>5]C:&L`<W1R8VAR`')E
M861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`
M86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`;&EB
M8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!?7VQI8F-?8W-U
M7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8VQE86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R
M7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R
M<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!P87)?
M:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A
M=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?
M,BXR+C4`1TQ)0D-?,BXQ-`!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'3$E"
M0U\R+C0````"``,``@`"`````@`"`````@````(``@````(````"``(`!``"
M``(````````````#``(`!0````(``P`"``(````&````!P````,``@``````
M```````````&```````"``,``@`"```````"``(```````(``@`#``8````"
M``(``@`&``$``0`!``$``0`!``$``0`!``$``0````$``0`!``$``0`!``(`
M`0`"``$``@`!``$``0`!`````@`!``$````!`````0`!`.`!```0````(```
M`'4::0D```,`LP0````````!``4`+P(``!``````````E)&6!@``!P"_!```
M$````'09:0D```8`R@0``!````!R&6D)```%`-8$```0````%&EI#0``!`#B
M!```$````'4::0D```(`LP0```````!@JR````````@`````````@"$`````
M``!HJR````````@`````````0"$````````(L"````````@`````````"+`@
M```````8L"````````@`````````<%H```````"XKR````````8````%````
M``````````#`KR````````8````*``````````````#(KR````````8````?
M``````````````#0KR````````8````C``````````````#8KR````````8`
M```K``````````````#@KR````````8````V``````````````#HKR``````
M``8````_``````````````#PKR````````8```!!``````````````!PJR``
M``````4```!/```````````````@L"````````4```!?``````````````!`
ML"````````4```!C``````````````!(L"````````4```!6````````````
M``!@L"````````4```!:``````````````#@K2````````<````!````````
M``````#HK2````````<````"``````````````#PK2````````<````#````
M``````````#XK2````````<````$````````````````KB````````<````&
M```````````````(KB````````<````'```````````````0KB````````<`
M```(```````````````8KB````````<````)```````````````@KB``````
M``<````+```````````````HKB````````<````,```````````````PKB``
M``````<````-```````````````XKB````````<````.``````````````!`
MKB````````<````/``````````````!(KB````````<````0````````````
M``!0KB````````<````1``````````````!8KB````````<````2````````
M``````!@KB````````<````3``````````````!HKB````````<````4````
M``````````!PKB````````<````5``````````````!XKB````````<````6
M``````````````"`KB````````<````7``````````````"(KB````````<`
M```8``````````````"0KB````````<````9``````````````"8KB``````
M``<````:``````````````"@KB````````<````;``````````````"HKB``
M``````<````<``````````````"PKB````````<````=``````````````"X
MKB````````<````>``````````````#`KB````````<````@````````````
M``#(KB````````<````A``````````````#0KB````````<````B````````
M``````#8KB````````<````D``````````````#@KB````````<````E````
M``````````#HKB````````<````F``````````````#PKB````````<````G
M``````````````#XKB````````<````H````````````````KR````````<`
M```I```````````````(KR````````<````J```````````````0KR``````
M``<````L```````````````8KR````````<````M```````````````@KR``
M``````<````N```````````````HKR````````<````O```````````````P
MKR````````<````P```````````````XKR````````<````Q````````````
M``!`KR````````<````R``````````````!(KR````````<````S````````
M``````!0KR````````<````T``````````````!8KR````````<````U````
M``````````!@KR````````<````W``````````````!HKR````````<````X
M``````````````!PKR````````<````Y``````````````!XKR````````<`
M```Z``````````````"`KR````````<````[``````````````"(KR``````
M``<````\``````````````"0KR````````<````]``````````````"8KR``
M``````<````^``````````````"@KR````````<```!```````````````"H
MKR````````<```!"``````````````"PKR````````<```!#````````````
M``!(@^P(2(L%994@`$B%P'0"_]!(@\0(PP```````````/\U2I,@`/\E3),@
M``\?0`#_)4J3(`!H`````.G@_____R5"DR``:`$```#IT/____\E.I,@`&@"
M````Z<#_____)3*3(`!H`P```.FP_____R4JDR``:`0```#IH/____\E(I,@
M`&@%````Z9#_____)1J3(`!H!@```.F`_____R42DR``:`<```#I</____\E
M"I,@`&@(````Z6#_____)0*3(`!H"0```.E0_____R7ZDB``:`H```#I0/__
M__\E\I(@`&@+````Z3#_____)>J2(`!H#````.D@_____R7BDB``:`T```#I
M$/____\EVI(@`&@.````Z0#_____)=*2(`!H#P```.GP_O___R7*DB``:!``
M``#IX/[___\EPI(@`&@1````Z=#^____);J2(`!H$@```.G`_O___R6RDB``
M:!,```#IL/[___\EJI(@`&@4````Z:#^____):*2(`!H%0```.F0_O___R6:
MDB``:!8```#I@/[___\EDI(@`&@7````Z7#^____)8J2(`!H&````.E@_O__
M_R6"DB``:!D```#I4/[___\E>I(@`&@:````Z4#^____)7*2(`!H&P```.DP
M_O___R5JDB``:!P```#I(/[___\E8I(@`&@=````Z1#^____)5J2(`!H'@``
M`.D`_O___R52DB``:!\```#I\/W___\E2I(@`&@@````Z>#]____)4*2(`!H
M(0```.G0_?___R4ZDB``:"(```#IP/W___\E,I(@`&@C````Z;#]____)2J2
M(`!H)````.F@_?___R4BDB``:"4```#ID/W___\E&I(@`&@F````Z8#]____
M)1*2(`!H)P```.EP_?___R4*DB``:"@```#I8/W___\E`I(@`&@I````Z5#]
M____)?J1(`!H*@```.E`_?___R7RD2``:"L```#I,/W___\EZI$@`&@L````
MZ2#]____)>*1(`!H+0```.D0_?___R7:D2``:"X```#I`/W___\ETI$@`&@O
M````Z?#\____)<J1(`!H,````.G@_/___R7"D2``:#$```#IT/S___\ENI$@
M`&@R````Z<#\____);*1(`!H,P```.FP_/___R6JD2``:#0```#IH/S___\E
MHI$@`&@U````Z9#\____)9J1(`!H-@```.F`_/___R62D2``:#<```#I</S_
M__\EBI$@`&@X````Z6#\____)8*1(`!H.0```.E0_/___R5ZD2``:#H```#I
M0/S___\EJI$@`&:0``````````!54TB#[#B)?"0<2(ET)!!(C7PD'$B)5"0(
M2(UT)!!(C50D"&1(BP0E*````$B)1"0H,<#H"/[__TB+-4F1(`!(BSU*D2``
M2(GRZ"(X``"`/9N1(```=2_H-/W__TB%P$B)!>JA(``/A+<!``!(B<?H;/S_
M_XL]5I$@`.C1_?__QH#1"````(L]1)$@`.B__?__@(BJ!````HL],I$@`.BM
M_?__@(BJ!````8M$)!R->`5(N/________\?2&/_2#G'#X<B`0``2,'G`TB-
M'0(Z``#H^?S__TB+?"002(D%5:$@`,<%4Z$@``0```!(BQ=(B5@(2(T=W#D`
M`$B)6!A(B1!(BQ6_D"``2(E0$(M4)!R#^@%$C4H$?BU$C4H$2(/'"+X%````
M9@\?A```````3(L'2&/.@\8!2(/'"$$Y\4R)1,CX=>E(BST"H2``36/)2(TU
MV!X``(/"`T4QP$K'1,CX`````$B)P>AA_?__A<")PW1D2(L]U*`@`$B-;"0D
MZ-K[__](C3T7.```,<!(B>[HN1<``$B%P'0J2(L]K:`@`.A8^___Z//\__^)
MV$B+7"0H9$@S'"4H````=5](@\0X6UW#2(L]>Z`@`$B%_W0LZ"DV``#KPTB+
M/7"@(`#HB_W__XG#ZXQ(C34PBR``2(T]7S<``#'`Z(+\__](C3U4-P``2(GN
MZ$,7``!(A<!(B<=(B04NH"``=(#KM.@-^___OP$```#H8_W__P\?`#'M28G1
M7DB)XDB#Y/!05$R-!:HV``!(C0TS-@``2(T]K/W___\5'H\@`/0/'T0``$B-
M/6F/(`!52(T%88\@`$@Y^$B)Y7092(L%ZHX@`$B%P'0-7?_@9BX/'X0`````
M`%W##Q]``&8N#Q^$``````!(C3TICR``2(TU(H\@`%5(*?Y(B>5(P?X#2(GP
M2,'H/T@!QDC1_G082(L%R8X@`$B%P'0,7?_@9@\?A```````7<,/'T``9BX/
M'X0``````(`](8\@``!U+TB#/9^.(```54B)Y70,2(L]JHX@`.C=_/__Z$C_
M___&!?F.(``!7<,/'X``````\\-F#Q]$``!52(GE7>EF____9@\?1```05=!
M5DR-3SA!54%413'`55-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)X6:0
M0XL$`4N+-`$/R$B)\HG`2,'J($J)!$%(B?!(P>XX2,'H*"4`_P``2`GP2(G6
M2,'B"$C!YAB!X@``_P")]D@)\$@)T$J)1$$(28/`"$F#^$!UKDB-L0`"```/
M'X``````2(M!:$@S04!(@\$(2#-!"$@S0?A(C10`2,'H'T@)T(/@_TB)07A(
M.?%UU4R+%TB+7Q!(BW<@2(MO&$R+3PA,B=!,B=)(P>H;2,'@!4@)T`,$)(V4
M,)EY@EI(B=A(BW0D"$@QZ$PAR$@QZ$B-M#69>8):1(TL`DR)RDR)R$C!Z`)(
MP>(>2`G"2(G838GHB=%)P>@;2#'(3"'02#'82`'P3(GN2,'F!4P)QD2-)`9,
MB=9,B=!(P>8>2,'H`D@)\$B+="0038GC2#'"2<'K&T&)P$PAZDB-M#.9>8):
M2#'*2`'R3(GF2,'F!4P)WD2-'!9,B>Y(BU0D&$G![0)(P>8>3`GN2#'P2(V4
M$9EY@EI,B=E,(>!!B?9,,<!(P>D;2`'03(G:2,'B!4@)RDR)X4G![`)$C2P"
M2,'A'DB+5"0@3`GA2(GP2#'(3(GN08G,3"'828V4$)EY@EI(P>X;3#'P2`'0
M3(GJ2,'B!4@)\D2-!`),B=I(BT0D*$G!ZP)(P>(>3`G:3(G&2#'128V$!IEY
M@EI(P>X;3"'I08G33#'A2`'!3(G`2,'@!4@)\$2--`A,B>A(BTPD,$G![0)(
MP>`>3`GH3(GV2#'"28V,#)EY@EI!B<5,(<),,=I(`<I,B?%(P>$%2,'N&T@)
M\4R)QDG!Z`)$C2012,'F'DB+5"0X3`G&2#'P3(GA08GP3"'P28V4$YEY@EI(
MP>D;3#'H2`'03(GB2,'B!4@)RDR)\4G![@)$C1P"2,'A'DB+5"1`3`GQ2(GP
M2#'(3(G>08G.3"'@28V4%9EY@EI(P>X;3#'`2`'03(G:2,'B!4@)\D2-+`),
MB>)(BT0D2$G![`)(P>(>3`GB3(GN2#'128V$`)EY@EI(P>X;3"'908G43#'Q
M2`'!3(GH2,'@!4@)\$2-!`A,B=A(BTPD4$G!ZP)(P>`>3`G83(G&2#'"28V,
M#IEY@EI(P>X;3"'J08G#3#'B2`'*3(G!2,'A!4@)\4R)[DG![0)$C3012,'F
M'DB+5"183`GN2#'P3(GQ08GU3"'`28V4%)EY@EI(P>D;3#'82`'03(GR2,'B
M!4@)RDR)P4G!Z`)$C20"2,'A'DB+5"1@3`G!2(GP2#'(3(GF08G(28V4$YEY
M@EI,(?!(P>X;3#'H2`'03(GB2,'B!4@)\D2-'`),B?)(BT0D:$C!XAY)P>X"
M3`GR3(G>2#'128V$!9EY@EI(P>X;3"'A08G63#'!2`'!3(G82,'@!4@)\$2-
M+`A,B>!(BTPD<$G![`)(P>`>3`G@3(GN2#'"28V,")EY@EI(P>X;3"':08G$
M3#'R2`'*3(GI2,'A!4@)\4R)WDG!ZP)$C0012,'F'DB+5"1X3`G>2#'P3(G!
M08GS3"'H28V4%IEY@EI(P>D;3#'@2`'03(G"2,'B!4@)RDR)Z4G![0)$C30"
M2,'A'DB+E"2`````3`GI2(GP2#'(3(GV08G-3"'`28V4%)EY@EI(P>X;3#'8
M2`'03(GR2,'B!4@)\D2-)`),B<)(BX0DB````$G!Z`)(P>(>3`G"3(GF2#'1
M28V$`YEY@EI(P>X;3"'Q08G03#'I2`'!3(G@2,'@!4@)\$B+M"20````1(T<
M"$R)\$G![@)(P>`>3`GP28VT-9EY@EI-B=U(,<))P>T;B<%,(>),,<)(`?),
MB=Y(P>8%3`GNB?9(`?),B>9)P>P"2,'F'D&)U4P)YDR+I"28````2#'P3"'8
M3XV$()EY@EI(,<A-B>Q)P>P;3`'`38GH2<'@!4T)X$6)P$P!P$V)V$G!ZP))
MP>`>08G$30G828GSB?9-,<-(`[0DJ````$0QVDR+G"2@````2HV,&:'KV6Y-
MB>-)P>L;2`'13(GB2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,">I-B<5%
MB<!),=5,`X0DL````$0QZ$V)W4B-M`:AZ]EN3(G82<'M&TC!X`5,">B)P$@!
M\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1$,>%-B>Q(`Y0DN````$V-A`BA
MZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G928GSB?9)
M,<M(`[0DP````$0QV$V)XTB-E`*AZ]EN3(G@2<'K&TC!X`5,"=B)P$@!PDR)
MZ$G![0)(P>`>08G33`GH28G-B<E),<5(`XPDR````$4QZ$V)W4Z-A`:AZ]EN
M3(G>2<'M&TC!Y@5,">Z)]DP!QDV)X$G![`))P>`>08GU30G@28G$B<!-,<1$
M,>)-B>Q(C8P1H>O9;DR)ZDC!X@5)P>P;2`.$)-````!,">*)TD@!T4R)VDG!
MZP)(P>(>08G,3`G:38G#18G`23'33`.$)-@```!$,=Y-B>-(C;0PH>O9;DR)
MX$G!ZQM(P>`%3`G8B<!(`?!,B>Y)P>T"2,'F'D&)PTP)[DF)U8G223'U2`.4
M).````!$,>E-B=U-C80(H>O9;DR)V4G![1M(P>$%3`GIB<E)`<A,B>%)P>P"
M2,'A'D6)Q4P)X4F)](GV23',1#'@38GL2(V4`J'KV6Y,B>A)P>P;2,'@!4P)
MX(G`2`'"3(G82`.T).@```!)P>L"2,'@'D&)U$P)V$F)RXG)23'#2`.,)/``
M``!%,=A-B>-.C80&H>O9;DR)YDG!ZQM(P>8%3`G>B?9,`<9-B>A)P>T"2<'@
M'D&)\TT)Z$F)Q8G`33'%2`.$)/@```!$,>I-B=U(C8P1H>O9;DR)VDG![1M(
MP>(%3`GJB=)(`=%,B>))P>P"2,'B'D&)S4P)XDV)Q$6)P$DQU$0QYDV)[$B-
MM#"AZ]EN3(GH2<'L&TC!X`5,">")P$@!\$R)WDC!YAY)P>L"3`.$)``!``!,
M"=Y)B=-!B<1),?.)TD@#E"0(`0``1#'938GC38V$"*'KV6Y,B>%)P>L;2,'A
M!4P)V8G)20'(3(GI2<'M`DC!X1Y%B<-,">E)B?6)]DDQS4@#M"00`0``1#'H
M38G=2(V4`J'KV6Y,B=A)P>T;2,'@!4P)Z(G`2`'"3(G@2<'L`DC!X!Y!B=5,
M">!)B<R)R4DQQ$4QX$V)[$Z-A`:AZ]EN3(GN2<'L&TC!Y@5,">:)]DP!QDV)
MV$G!ZP))P>`>08GT30G82`.,)!@!``!)B<--,<.)P$@#A"0@`0``1#':38GC
M2<'K&TB-C!&AZ]EN3(GB2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,">I-
MB<5%B<!),=5,`X0D*`$``$0Q[DV)W4B-M#"AZ]EN3(G82<'M&TC!X`5,">B)
MP$@!\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1(`Y0D,`$``$0QX4V)[$V-
MA`BAZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G928GS
MB?9),<M$,=A-B>-(`[0D.`$``$B-E`*AZ]EN3(G@2<'K&TC!X`5,"=A$C1P0
M3(GH2<'M`DC!X!Y,">A)B<V)R4DQQ8G"13'H38G=3HV$!J'KV6Y,B=Y)P>T;
M2,'F!4P)[DR+K"1``0``1HTT!DV)X$G![`))P>`>30G@3`G`1(G&28G$2(G0
M2"'P32'<20G$N-R\&X])`<5,`>E-B?5)`<Q,B?%)P>T;2,'A!4P)Z4F)]4$!
MS$R)V4G!ZP)(P>$>3`G908G+20G(32'P32'=30GH3(NL)$@!``!)`<5,`>I-
MB>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"2,'B'DP)\DV)WD&)T$@)
MT4TAQDPAX4P)\4R+M"10`0``20'&3`'V38GN2`'Q3(GN2<'N&TC!Y@5,"?9$
MC30.3(GF2<'L`DC!YAY,">9-B<2)\4@)\DDAS$PAZDP)XDR+I"18`0``20'$
M30'C38GT3`':38GS2<'C!4G![!M-">-%C20338GK2<'M`DG!XQY-">M)B<U$
MB=I,"=Y)(=5,(?9,">Y,BZPD8`$``$D!Q4T!Z$V)Y4P!QDV)X$G![1M)P>`%
M30GH18TL,$V)\$G![@))P>`>30GP28G61(G&30G#22'V32'C30GS3(NT)&@!
M``!)`<9,`?%-B>Y)`<M,B>E)P>X;2,'A!4P)\4:--!E,B>%)P>P"2,'A'DP)
MX4F)]$&)RTD)R$TAZ$TAW$T)X$R+I"1P`0``20'$3`'B38GT20'03(GR2<'L
M&TC!X@5,">)&C20"3(GJ2<'M`DC!XAY,">I-B=U!B=!("=%-(<5,(?%,">E,
MBZPD>`$``$D!Q4P![DV)Y4@!\4R)YDG![1M(P>8%3`GN1(TL#DR)]DG![@)(
MP>8>3`GV38G&B?%("?))(<Y,(>),"?),B[0D@`$``$D!QDT!\TV)[DP!VDV)
MZTG!XP5)P>X;30GS18TT$TV)XTG![`))P>,>30GC28G,1(G:3`G>22'43"'N
M3`GF3(ND)(@!``!)`<1-`>!-B?1,`<9-B?!)P>P;2<'@!4T)X$6-)#!-B>A)
MP>T"2<'@'DT)Z$F)U42)QDT)PTDA]4TA\TT)ZTR+K"20`0``20'%3`'I38GE
M20'+3(GA2<'M&TC!X05,">E&C2P93(GQ2<'N`DC!X1Y,"?%)B?9)"<A!B<M-
M(=Y-(>!-"?!,B[0DF`$``$D!QDP!\DV)[DD!T$R)ZDG![AM(P>(%3`GR1HTT
M`DR)XDG![`)(P>(>3`GB38G<08G02`G132'$3"'I3`GA3(ND)*`!``!)`<1,
M`>9-B?1(`?%,B?9)P>P;2,'F!4P)YD2-)`Y,B>Y)P>T"2,'F'DP)[DV)Q8GQ
M2`GR22'-3"'R3`GJ3(NL)*@!``!)`<5-`>M-B>5,`=I-B>-)P>T;2<'C!4T)
MZT6-+!--B?-)P>X"2<'C'DT)\TF)SD2)VDP)WDDAUDPAYDP)]DR+M"2P`0``
M20'&30'P38GN3`'&38GH2<'N&TG!X`5-"?!%C30P38G@2<'L`DG!X!Y-">!)
MB=1$B<9-"<-)(?1-(>M-">-,BZ0DN`$``$D!Q$P!X4V)]$D!RTR)\4G![!M(
MP>$%3`GA1HTD&4R)Z4G![0)(P>$>3`GI28GU08G+20G(32'P32'=30GH3(NL
M),`!``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"2,'B
M'DV)V$P)\D&)UD@)T4TA\$PAX4P)P4R+A"3(`0``20'`3`'&38GH2`'Q3(GN
M2<'H&TC!Y@5,"<9$C00.3(GF2<'L`DC!YAY,B?%,">9!B?1("?),(>%,(>I(
M"<I(BXPDT`$``$@!P4D!RTR)P4@#A"38`0``3`':38G#2,'A!4G!ZQM,"=F)
MR4P!\$@!RDR)Z4G![0)(P>$>08G33`GI38GE08G/2`G.32']3"'&3`GN38G=
M2`'P3(G>2<'M&TC!Y@5,">Z)]D@!\$R)QDG!Z`)(P>8>08G%20GPOM;!8LI,
M,<$QRDB+C"3@`0``2`'Q20',3(GI3`'B38GL2,'A!4G![!M,">&)R4@!RDR)
MV4C!X1Y)P>L"08G420G+3(G!38GF3#'92<'N&T6)P#'(2(N,).@!``!(`?%)
M`<]*C0PX3(G@2,'@!4P)\(G`3(TT`4R)Z$G![0)(P>`>3(G918G;20G%2(N$
M)/`!``!%B?=,,>DQRDR)^4@!\$C!Z1M,`<!(`<),B?A(P>`%2`G(2(N,)/@!
M``")P$@!PDR)X$G![`)(P>`>2`'Q08G03`G@3`'938GK23'#38G$18GM13'>
M2<'L&TZ-'#%,B<%(P>$%3`GAB<E)`<M,B?E)P>\"2,'A'D6)W$D)STB+C"0`
M`@``2`'Q3`'I28G%B<!-,?U$,>I,C2P13(GB3(GA2,'I&TC!X@5("<I,B<%)
MP>@"B=)(P>$>20'52(N4)`@"``!,"<%-B?A%B>Y%B?]),<A(`?)%,<-(`=!,
MB?).C0083(GP2,'J&TC!X`5("=!(B<J)R8G`20'`3(G@2<'L`DC!X!Y%B<-)
M"<1(BX0D$`(``$PQXD$QU4R)VD@!\$P!^$D!Q4R)V$C!X`5(P>H;2`G03(GR
M2<'N`HG`2,'B'DD!Q4B+A"08`@``3`GR18GO2`'P2`'(3(GA18GD2#'103'(
M3(GY20'`3(GX2,'I&TC!X`5("<B)P$D!P$R)V$G!ZP)(P>`>18G&20G#2(N$
M)"`"``!,B?%(P>D;2`'P3`'@28G4B=)-,=Q%,>5.C20H3(GP2,'@!4@)R$B+
MC"0H`@``B<!)`<1,B?A)P>\"2`'Q2,'@'D6)Y4P)^$@!RDR)V4@QP46)VT$Q
MR$R)Z4D!T$R)ZDC!Z1M(P>(%2`G*B=))`=!,B?))P>X"2,'B'D6)QTD)UDB+
ME"0P`@``3(GY2,'I&T@!\DP!VDF)PXG`33'S13'<3HT<(DR)^DC!X@5("<I,
MB>E)P>T"B=)(P>$>20'32(N4)#@"``!,">E%B=Q(`?)(`=!,B?)%B?9(,<I!
M,=!,B>))`<!,B>!(P>H;2,'@!4@)T$B)RHG)B<!)`<!,B?A)P>\"2,'@'D6)
MQ4D)QTB+A"1``@``2`'P3#'Z3`'P03'33(GJ20'#3(GH2,'J&TC!X`5("=!,
MB>))P>P"B<!(P>(>20'#2(N$)$@"``!,">)%B=Y)B=1(`?!(`<A,B?E%B?](
M,=&)TD$QR$J-#`!,B?!-B?!)P>@;2,'@!4P)P(G`2`'!3(GH2<'M`DC!X!Y!
MB<A)"<5(BX0D4`(``$TQ[$4QXTV)Q$@!\$G![!M,`?A)`<-,B<!(P>`%3`G@
MB<!)`<-,B?!(P>`>2<'N`D6)W$P)\$R+M"18`@``20'V20'63(GJ18GM2#'"
M,=%)C10.3(GA38GF2<'N&TC!X05,"?&)R4@!RDR)P4G!Z`)(P>$>08G620G(
M2(N,)&`"``!(`?%,`>E)B<6)P$TQQ44QZTV)]4D!RTR)\4G![1M(P>$%3`GI
MB<E)`<M,B>%)P>P"2,'A'D6)W4D)S$B+C"1H`@``2`'Q2`'(3(G!18G`3#'A
M,<I(C0P03(GH3(GJ2,'J&TC!X`5("=!,B?))P>X"2,'B'HG`20G62(N4)'`"
M``!(`<&)R$@!\DP!PDV)X$TQ\$4QPTF)P$P!VDF)PTG!X`5)P>L;30G828G#
M2,'H`DG!XQY!`=!,B>I)"<-(BX0D>`(``$C!XAY)P>T"00';20G51(GB3(E?
M$$@!\$0![4@!PDR)\$B);QA,,>@QP4B-!`I,B<),B<%(P>(%2,'I&T4!R$@)
MRDR)1P@!T$$!PD0#=R!(BX0DB`(``&1(,P0E*````$R)%TR)=R!U$DB!Q)@"
M``!;74%<05U!7D%?P^CBX___9I!!5T%6055!5%532(/L"$B%_P^$L0```$R+
M/8IX(`!-A?\/A*$````/M@>$P'0$/#UU7D4QY$F+'TB%VW0Y28GU28G^36/D
M3(G]#Q^``````$R)XDR)]DB)W^C"XO__A<!U!T*`/",]=$=(@\4(2(M=`$B%
MVW7:2(/$"$B)V%M=05Q!74%>05_##Q^$``````!)B?Q)@\0!00^V!"2$P'0$
M/#UU[T$I_.N,#Q^``````$PI_4J-7",!2,']`T&);0#KM&8/'T0``#';ZZH/
M'T``55-(B?U(@^P89$B+!"4H````2(E$)`@QP$B-7"0$9I`QP$B)WDB)[^@#
M____2(7`=#9(8U0D!$B+!9IW(`!(C0302(M0"$B%TDB)$'329I!(@\`(2(M0
M"$B%TDB)$'7PZ[YF#Q]$``!(BT0D"&1(,P0E*````'4'2(/$&%M=P^B,XO__
M9I!F+@\?A```````05=!5D%505154TB)\TB)_4B#["AD2(L$)2@```!(B40D
M&#'`,<"`/CT/E,!(`<-(B=_H.>+__TB-="0428G$2(GO,<#H5_[__TB%P`^$
M#@$``$B)QTF)Q>@3XO__3#G@#X/B````3&-T)!1)P>8##[9%`(3`#X2M`0``
M/#T/A*4!``!(B>CK#0\?A```````@/H]=`M(@\`!#[80A-)U\$@IZ$B83`,U
MG'8@`$J-?"`"Z/KB__](A<!)B08/A'L!``!(8U0D%$B+!7IV(`!(C4T!2(L4
MT`^V10`\/8@"=":$P'40ZR!F+@\?A```````/#UT$DB#P0$/MD'_2(/"`83`
MB`)UZL8"/3'`#Q]$```/M@P#B$P"`4B#P`&$R77P,<!(BW0D&&1(,S0E*```
M``^%$0$``$B#Q"A;74%<05U!7D%?PP\?`$B#PP$/MD/_28/%`83`08A%_W7L
MZ\)FD$R+/>%U(`!)@S\`#X2_````3(GX,=+K"P\?A```````1(GJ2(/`"$2-
M:@%(@S@`=>^-<@-(8_9(P>8#BP7?A2``A<!U6TB)]\<%SH4@``$```#H^>'_
M_TB%P`^$?0```$UCQ4R)_DB)QTZ--,4`````3(E$)`A,B?+H@N+__TR+1"0(
M2(G!2(D%6W4@`$K'1,$(`````$2);"04Z6_^__],B?_H..+__TB%P$B)P4B)
M!3-U(`!T)DUCQ4Z--,4`````Z\D/'T``,<#I=O[__Y"^$````$4Q[>E>____
MN/_____IV_[__^@TX/__#Q]``$%7059!54%455-(@>RX````9$B+!"4H````
M2(F$)*@````QP$B%_W0(@#\`28G^=2](BX0DJ````&1(,P0E*`````^%)`$`
M`$B!Q+@```!;74%<05U!7D%?PV8/'T0``.AKW___2(7`2(G#=,1(C40D$$B-
M+8P;``!,C26$&P``3(T]@!L``$B)!"1(B=_HC>'__TB%P`^$M````$R-2!.Y
M`@```$B)[TR)SO.F=-RY`P```$R)SDR)Y_.F=,U,B?=,B4PD".A5W___3(M,
M)`A)B<5,B<_H1=___T&-?`4"2&/_Z'C@__],BTPD"$F)Q4B)QTV)\$R)^4C'
MPO____^^`0```#'`Z-3A__](BQ0DOP$```!,B>[HH][__X/X_TR)[W00BT0D
M*"4`\```/0!```!T,.@FWO__3(GOZ/[=___I1/___V8/'X0``````$B)W^A8
MW___3(GWZ+#>___IS/[__^B6_O__Z\[HO][__P\?1```9BX/'X0``````%-(
MB?Y(B?N_`0```$B![*````!(B>)D2(L$)2@```!(B80DF````#'`Z-+@__^%
MP'4^BU0D&('B`/```('Z`$```'0T@?H`H```="Q(BXPDF````&1(,PPE*```
M`'4P2('$H````%O##Q^$```````QP.O8#Q]``+X"````2(G?Z#O@__^%P`^4
MP`^VP.N]Z!S>__]FD&8N#Q^$``````!!5D%528GV051528G\4TB-/=@9``"Z
M_P\``$B![!`0``!(B>-(B=YD2(L$)2@```!(B80D"!```#'`Z#'=__^%P`^.
MB0```(U0_T2++5]R(`!(8^J`/"P`=%9(8^A(B>J^+P```$B)W^A3WO__2(7`
M=$9$B>_HMM[__TB)Z4B)VDR)YDB)Q^BUW___2(N$)`@0``!D2#,$)2@```!U
M.TB!Q!`0``!;74%<05U!7L-FD(72=:D/'T``1(GOZ'#>__],B?),B>9(B<?H
M@MW__^N[1(LMV7$@`.O?Z#+=__]FD$B#[`B+/<9Q(`#H0=[__TB+%5IQ(`!(
MC0WK&@``2(TU^!@``$B)QTB#Q`CI8-[__TB#[`B+/99Q(`#H$=[__TB)Q^BY
M____BSV#<2``Z/[=__],C058&@``2(T5L!,``$B--=$8``!%,<E(B<=(@\0(
M3(G!Z6?>__\/'X``````55-(@>PH(```9$B+!"4H````2(F$)!@@```QP$B)
MXTB-K"00$```Z`3<__],C0UE&```2(T-DQ@``$&)P+H!$```O@$```!(B=\Q
MP.@/W___N@`0``!(B>Y(B=_HK]O__X7`>%.->`%(B<-(8__H;=W__TB%P$B)
MP7082&/;2(GN2(G'2(G:Z"3=__](B<'&!!@`2(N4)!@@``!D2#,4)2@```!(
MB<AU$TB!Q"@@``!;7<,/'T0``#')Z]?H[]O__P\?1```9BX/'X0``````.DK
M____D&8N#Q^$``````!!5T%6055!5$F)]%532(G[2(T]XA<``$B![+@0``!D
M2(L$)2@```!(B80DJ!```#'`2(UT)`SHM??__[XO````2(G?2(G%Z*7;__](
MA<!T0$B-/:L7``!(B=XQP.CO^/__2(G82(N,)*@0``!D2#,,)2@````/A7H!
M``!(@<2X$```6UU!7$%=05Y!7\,/'P!(B=_H*-O__TB--7`7``!,B>=!B<7H
M1MW__TB%P$F)QW2>08/%`4&`/P!,C:0DH````$R-="00#X3)````#Q\`2(7M
M=!-,B?Y(B>_HP-O__X7`#X2*````3(G_Z-#:__^)PDB808!\!_\O=1</'T``
M@^H!2&/"08!\!_\O0<8$!P!T[40!ZH'Z_P\```^/+O___TB#[`A(C0W:%P``
M3(T-W18``%--B?BZ`!```+X!````3(GG,<#H--W__TR)\DR)YK\!````Z`3:
M__^%P%I9=1"+1"0H)0#P```]`(```'162(TUEA8``#'_Z'#<__](A<!)B<</
MA,3^__]!@#\`#X4Z____2(7M=!5(C3T#%@``N0(```!(B>[SIG3$9I!,C3WN
M%0``N@$```#I4O___P\?@`````"^`0```$R)Y^@+W/__A<!UF4B-/2(6``!,
MB>;H:/?__TR)Y^APW/__Z6_^___HUMG__V8/'T0```^V%TB)^(32=!YF#Q]$
M``!(@\<!@/HO#[872`]$QX32=>[SPP\?0`#SPV8/'T0``$B%_P^$SP```%53
M2(/L"`^V+T"$[70I2(G[Z''9__](C50#_T@YTW(0ZSL/'T0``$B#Z@%(.=-T
M-X`Z+W3RZQU(@\0(2(T]*A4``%M=Z=[;__]F#Q]$``"`.B]T.$B#Z@%(.=-R
M\D@YTW4J#Q]$``!`@/TO=,I(@\0(2(T]8!4``%M=Z:C;__\/'X0``````(`Z
M+W4)2(/J`4@YTW+R2"G:2(U"`D@]`!```'<[2(T][&T@`$B#P@&Y`!```$B)
MWNAKVO__2(T%U&T@`$B#Q`A;7<,/'T0``$B-/984``#I3-O__P\?0``QP.O@
M#Q]``%-(C3WK%```2(/L0&1(BP0E*````$B)1"0X,<`/MP5=%@``2(U<)`SS
M#V\%,!8```\I1"009HE$)#`QP/,/;P4L%@``#RE$)"#H4O7__TB-/:<4```Q
MP.A$]?__2(T]H10``#'`Z#;U__](C3V<%```,<#H*/7__TB-/944```QP.@:
M]?__2(T]EQ0``#'`Z`SU__](C3T^%```,<#H_O3__TB-/8<4```QP.CP]/__
M2(T]@Q0``#'`Z.+T__](C3U_%```,<#HU/3__TB-/0\4```QP.C&]/__2(T]
M;10``#'`2(G>Z.7S__](A<!T$4B-/4,4``!(B<8QP.@O]?__2(T]5Q0``#'`
M2(G>Z+[S__](A<!T$4B-/5,4``!(B<8QP.@(]?__2(T]310``#'`2(G>Z)?S
M__](A<!T0DB-/903``!(B<8QP.CA]/__2(TU4A0``$B-/;<3```QP.C,]/__
M2(M$)#AD2#,$)2@```!U8DB#Q$!;PV8/'T0``$B-/044```QP$B)WN@_\___
M2(7`=2I(C70D(4B-/?L3``"Y"@```/.F=:1(C70D*TB-/7D3```QP.AR]/__
MZX](C3UI$P``2(G&,<#H7_3__^EY____Z-76__\/'T0``$B#[!AD2(L$)2@`
M``!(B40D"#'`BP5&:R``@_C_=!E(BWPD"&1(,SPE*````'5`2(/$&,,/'T``
M2(UT)`1(C3T,$P``,<#HI?+__TB)PC'`2(72=!(/MA*`^C`/E<$QP(32#Y7`
M(<B)!?-J(`#KL.A<UO__9I!F+@\?A```````2(/L".A7UO__B<?H`-;__TB%
MP'0+2(L`2(/$",,/'P`QP.OT9I!F+@\?A```````05152(G]4TB-/0P3``!(
M@^P09$B+!"4H````2(E$)`@QP$B-="0$Z!3R__](A<!(B>YT?(`X`$B)PW1T
M2(G'Z'S8__](A<!U=4B)[^B_U?__2(G?28G$Z+35__])C7P$`NCJUO__2(/L
M"$R-#>X1``!(C0W?$@``4TC'PO____](B<=)B<1)B>B^`0```#'`Z#O8__](
MC3U^$@``3(GF,<#H^O+__UA:ZQ1F#Q]$``!(C3UC$@``,<#HXO+__TB+1"0(
M9$@S!"4H````=0E(@\006UU!7,/H1-7__P\?0`!!5T%628G^055!5$B-/5<1
M``!54TB![)B!``!D2(L$)2@```!(B80DB($``#'`2(T%(1(``$R-9"0L2,=$
M)$``````2,>$))@`````````2,=$)&``````2(E$)#!(C06Q$```3(GF2(E$
M)#A(C06.$0``2(E$)'!(C05[$0``2(E$)'A(C070$0``2(F$)(````!(C05]
M$0``2(F$)(@```!(C06Z$0``2(F$))````!(C062$0``2(E$)%!(C06C$0``
M2(E$)%@QP.B0\/__2(7`=`F`.``/A6("```QP.@+_O__2(7`2(G##X2?`@``
M2(G?Z#?4__](C7P``>AMU?__@#L`28G%=#=,C3U>$0``3(GM#Q\`1`^V`TB)
M[S'`3(GY2,?"_____[X!````2(/#`4B#Q0+HL];__X`[`'762(U<)'!(C3VS
M$```ZQ!(@\,(2(L[2(7_#X2``0``,<!,B>;H]N___TB%P$B)Q73>@#@`=-E(
MB<?H$?7__X7`=,U(B>_H1=;__TB%P$F)QP^$20$``&8/'X0``````$R)^HL*
M2(/"!(V!__[^_O?1(<@E@("`@'3IB<'!Z1"I@(````]$P4B-2@)(#T31B<$`
MP4R)Z4B#V@-,*?J+,4B#P02-AO_^_O[WUB'P)8"`@(!TZ8G&P>X0J8"````/
M1,9(C7$"2`]$SHG&0`#&2(/9`TPIZ8V<"@0$``!(8]M(B=_H2=3__TB)Q4B-
M!4T0``!!54R-#4</``!(C0TT$```38GX4$C'PO____^^`0```$B)[S'`Z)75
M__^^P`$``$B)[^@HTO__@_C_05A!6742Z.K1__]$BPA!@_D1#X63"```3(VL
M)*````!(B>Z_`0```$R)ZNCUU/__A<!!B<=U%XN$)+@````E`/```#T`0```
M#X1'`0``28L.2(L]76<@`$B-%9X0``!)B>B^`0```#'`,=OHY=3__^F`````
M,>UF#Q]$``!(8\5(BUS$,$B%VW0[@#L`=#9(B=^#Q0'HB_/__X7`=-](B=_H
MO]3__TB%P$F)QP^%@_[__TACQ4B+7,0P2(7;=<MF#Q]$``!%,?_I:/[__P\?
MA```````2(G'2(D$).C4^___2(L$)$B)Q^AXU/__2(G##Q]$``!(BXPDB($`
M`&1(,PPE*````$B)V`^%E0@``$B!Q)B!``!;74%<05U!7D%?PP\?0`!(C3VS
M#@``,>U(A?]T)F:0,<!,B>:#Q0'HL^W__TB%P'0%@#@`=2E(8\5(BWS$4$B%
M_W7<OPT```!(C1U_#@``Z)O2__])B<7I+OW__P\?`$B)Q^CHT___2(7`2(G#
M#X7]_/__Z\%F+@\?A```````BX0DO````(D$).A!T?__.00D#X6A_O__BX0D
MN````"7_`0``/<`!```/A8K^__](B=_H.=+__TB-/0<.``!(B<-,B>8QP.@5
M[?__2(7`#X1<`0``2(G'Z'33__])BSY(B<;H"?7__TB%P$F)Q`^$/0$``$R)
MY^BUT/__@_@#?CA(8]!(C3WY#0``N04```!)C704_/.F=2"#^`0/A.\%``"#
MZ`1(F$&`?`3_+P^$W@4``&8/'T0``#'`Z+'Y__^%P'45,?9,B>?H0]+__X7`
M08G&#X7H````2(TU60T``$B-/=H,``!,C274#0``,<!,C2V+#```Z,7M___H
MP,___T%43(T->`P``%!(C0V+#0``2,?"_____TF)Z+X!````2(G?,<#HQM+_
M_UA:ZT5FD.@KS___@S@1=4OH@<___T&#QP%(@^P(2(T-7`T``$%405=-B>E0
M28GH2,?"_____[X!````2(G?,<#H@=+__TB#Q""^P`$``$B)W^@0S___@_C_
M=*M(B>_HP\[__TB-/=4+``!(B=XQP.@B[?__2(G?Z'KY___IM?W__P\?1```
M38LFZ;O^__\/'X0``````+H"````2,?&[O___XG'Z-W1__](C80D@`$``+H&
M````1(GW2(G&2(D$).@1T/__@+PD@`$```!U#H"\)($!``!##X1X!0``,=(Q
M]D2)]^B=T?__N(FKS>](QX0DH`````$C16=(QX0DN````'94,A!(B80DJ```
M`$@MB\X25TC'A"3(`````````$B)A"2P````2`7R!!@K2,>$)-``````````
M2(F$),````!)C44XQX0D&`$```````!(B40D"$B+-"2Z`(```$2)]^AOS___
MA<!)B<1!B<`/CG$!``!(B[PDR````$ECQ$B+E"30````C33'2#G^2(FT),@`
M``!(@](`2,'H'4@!T$B)A"30````2&.$)!@!``"%P`^$'0$``$B+3"0(0;A`
M````2(LT)$$IP$4YQ$4/3L1(C3P!26/028G72(E4)!#H,,___XN$)!@!``!$
M`?B#^$")A"08`0``#X56____18G@3(GO12GX3(M\)!!,`SPD1(E$)!SH"M3_
M_T2+1"0<#Q]$``!!@_@_?GE!C4#`B40D','H!D&)Q(E$)!!)@\0!2<'D!DT!
M_`\?1```\T$/;P=,B>])@\=`#Q&$)-@```#S00]O1]`/$80DZ````/-!#V]'
MX`\1A"3X````\T$/;T?P#Q&$)`@!``#HE=/__TTY_'6XBT0D$$2+1"0<P>`&
M02G`2(M\)`A)8]"Y2````$R)_D2)1"00Z$?.__]$BT0D$$2)A"08`0``Z87^
M__\/'T0``$R+/"3I1____P\?@`````!$B??HF,W__TR+I"3(````3(NT)-``
M``!,B>!(P>@#@^`_C5`!2)C&A`38````@(/Z.`^/@P(``+@X````,?8IT$AC
MTH/X"$F-5!4X#X/;`@``J`0/A88#``"%P'0+J`+&`@`/A8H#``!,B?!,B>]$
MB+0D$P$``$C!Z!A$B*0D%P$``$R-K"10`0``B(0D$`$``$R)\$C!Z!"(A"01
M`0``3(GP3(TUM@D``$C!Z`B(A"02`0``3(G@2,'H&(B$)!0!``!,B>!(P>@0
MB(0D%0$``$R)X$4QY$C!Z`B(A"06`0``Z%G2__](BX0DH````$B)PHB$)#,!
M``!(P>H81`^VPHB4)#`!``!(B<)(P>H0B)0D,0$``$B)PDB+A"2H````2,'J
M"(B4)#(!``!(B<*(A"0W`0``2,'J&(B4)#0!``!(B<)(P>H0B)0D-0$``$B)
MPDB+A"2P````2,'J"(B4)#8!``!(B<*(A"0[`0``2,'J&(B4)#@!``!(B<)(
MP>H0B)0D.0$``$B)PDB+A"2X````2,'J"(B4)#H!``!(B<*(A"0_`0``2,'J
M&(B4)#P!``!(B<)(P>H0B)0D/0$``$B)PDB+A"3`````2,'J"(B4)#X!``!(
MB<*(A"1#`0``2,'J&(B4)$`!``!(B<)(P>H0B)0D00$``$B)PDC!Z@B(E"1"
M`0``Z0P````/'P!&#[:$)#`!``!+C7QE`#'`3(GQ2,?"_____[X!````28/$
M`>BHS?__28/\%'722(T%;`@``,:$)'@!````4$%52(T-)@@``$R-#1,'``"^
M`0```$F)Z$C'PO____](B=\QP.AIS?__65[I]_K__V:038MV"$V%]@^$&_K_
M_TR)]^B+RO__2(/X`P^&"?K__TF-=`;\2(T]S0<``+D%````\Z9-#T3FZ>WY
M__^X0````$ACRBG028U,#3AT#S'2B=:#P@$YPL8$,0!R\TR)[^A=T/__9@_O
MP`\1A"38````2<=%:`````!!#Q%%2$$/$458Z6/]__])BPY(BST`7R``2(T5
M`0@``$F)Z+X!````,<`QV^B(S/__Z2/X__^)P4C'`@````!(QT0*^`````!(
MC4H(2(/A^$@IR@'0@^#X@_@(#X(1_?__@^#X,=*)UX/""#G"2(DT.7+SZ?K\
M__^`O"2"`0``00^%>OK__X"\)(,!``!##X5L^O__@+PDA`$``$@/A5[Z__^`
MO"2%`0``10^%4/K__[H"````2,?&QO___T2)]^CER___3(L\)+HI````1(GW
M3(G^Z"'*__](C07;!@``4$%7Z7+^__]FD,<"`````,=$`OP`````Z7;\__\Q
M_V:)?`+^Z6K\___H+,G__V:09BX/'X0``````$%7059!54%455-(@^P8BSVL
M72``9$B+!"4H````2(E$)`@QP$R-;"0$Z!+*__^+/8Q=(`!(B</H!,K__P^V
MD[@```!(C3TZ!0``3(GNB)"Y````,<#HYN3__TB%P'0)@#@Q#X0(`P``,<#H
M`?#__XL]2UT@`.C&R?__2(TU&@8``+D+````N@$```!(B<?H;<G__TB%P`^$
MQ````(,]C6T@``%(BT`01(LU$ET@`$R+8"@/CJ\````Q[;L!````ZSH/'X``
M````28MW$$B+!55M(`!(8]-(BSS0Z!')__^%P(L526T@``^%"`(``(/#`8/%
M`3G3#XWZ`0``1(GWZ#W)__\QR4ACU4R)YDB)Q^@-RO__2(7`#X3,`0``3(LX
M1(LUFEP@`$&+1PPE``0@`#T`!```=))$B??H`LG__TR)_KD"````,=)(B<?H
M(,C__T2+-6E<(`!(B<;I;?___Y!$BS597"``1(GWZ-'(__](C34J!0``N0,`
M``"Z`0```$B)Q^AXR/__2(7`2(G#=#5(BT`0BSTF7"``2(LHZ)[(__](C17Y
M!```2(G'2(GNZ*S'__](BT,02(L8]D,.0`^%ZP$``(L]]5L@`.APR/__2(TU
MT`0``+D#````N@$```!(B<?H%\C__TB%P$B)PW0]2(T]6@,``#'`3(GNZ#[C
M__](A<!(B<4/A'(!``!(BT,0BSVH6R``2(L8Z"#(__](B>I(B<=(B=[H,L?_
M_XL]C%L@`.@'R/__2(TU:00``+H!````2(G'Z!/(__^+/6U;(`!(B</HY<?_
M_TB-%5P$``!(B=Y(B<?H\\;__XL]35L@`.C(Q___2(T]R@(``,:`N0````!,
MB>XQP.BPXO__2(7`2(G#2(D%FVL@``^$G0```+[``0``2(G?Z,#%__^-4`&#
M^@%V"8/X$0^%#P$``$B+1"0(9$@S!"4H````#X7V````2(/$&%M=05Q!74%>
M05_##Q]``(L50FL@`$2+-<M:(`"-0O\YZ`^%9_[__X/Z`0^.7O[__[L!````
M9I!$B?>#PP'H)<?__TR)YDB)Q^AJQ?__.1T$:R``1(LUC5H@`'_;Z2W^__]F
M#Q]$``!(BSWA:B``Z)3P__](A<!(B<-(B07?:B``#X5$____2(T].@0``#'`
MZ`/'__\/'P"`>`$`#X3U_/__Z>G\__^02(L%H6H@`(L],UH@`$B+*$B+0Q!(
MBQCHI,;__TB)[DB)W^AIY___Z8+^__\/'T``BST*6B``Z(7&__](B=Y(B<?H
MVL;__^GZ_?__Z%#%__^)P4B+!4]J(`!(C3WH`P``2(G:2(LP,<#H@\;__P\?
M`%532(G]2(/L".B"Z___#[802(G#A-)T&@\?A```````2(/``8#Z+P^V$$@/
M1-B$TG7N,<#H)^[__TB%[70=A<!T&8!]``!T$TB-/1\"``"Y!````$B)WO.F
M=`=(@\0(6UW#2(/$"$B)[UM=Z9#D__](BPU!62``Z43%__\/'T``05=!5DF)
MUT%5051,C25^5"``54B-+7Y4(`!308G]28GV3"GE2(/L"$C!_0/H7\/__TB%
M[70@,=L/'X0``````$R)^DR)]D2)[T'_%-Q(@\,!2#G==>I(@\0(6UU!7$%=
M05Y!7\.09BX/'X0``````//#``!(@^P(2(/$",,````!``(`+BX`)7,O)7,`
M+W!R;V,O<V5L9B]E>&4`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN
M=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!4E]0
M4D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`
M4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"
M54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$
M25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!
M3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0051(`%5315(`4UE35$5-`"]T
M;7``5$5-4$1)4@!435``55-%4DY!344`)3`R>``E<R5S)7,E<P!P87(M`'!A
M<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP
M+25U+25U)7,`05)'5@`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q
M+C`T-0`M90`M+0````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@(```````````<&5R;'AS:2YC`````````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@
M)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!
M3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG
M(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T
M:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I
M.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE
M("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,
M051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER
M;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L
M"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL
M="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A
M<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@
M*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO
M9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA
M;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M
M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O
M('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*
M0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM
M>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP
M871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*
M7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI
M+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?
M<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI[
M"FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG
M+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM
M>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@
M)&ED>"`]("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F
M9G-E="`^("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q
M6W-E96L@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`]
M(')E860@7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@
M;VX@(B1P<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970[
M"B1I9'@@/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D
M:61X(#X](#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X
M("H@,3`R-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@
M,#L*)&]F9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP
M86-K*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@
M*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B
M=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*
M;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I
M(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]
M?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE
M9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*
M;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W
M-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL
M96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F
M=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@
M86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`]
M(%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S
M*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES
M='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL
M;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D
M9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.
M0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I
M9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L
M971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF
M;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1
M)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I
M<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D
M(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*
M<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL
M96YA;64@/2!?=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL
M96YA;64M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R
M(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I
M.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A
M;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO
M861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y
M.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I
M;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE
M<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I
M('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I
M;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M
M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<
M,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`
M<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N
M86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@
M*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@
M=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D
M05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D
M:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R
M"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A
M<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS
M:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6
M.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O
M7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),
M8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S
M:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L
M(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R
M7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]
M"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I
M9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@
M97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO
M<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N
M(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@
M/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD
M>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL
M97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6
M.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF
M("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@
M*&1E9FEN960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q
M,C@J,3`R-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN
M;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L
M("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B
M.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z
M:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R
M.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;
M7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I
M;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D
M<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I
M;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T
M:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&
M:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&
M:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F
M:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U
M;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&
M2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>
M*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R
M+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY
M("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@
M:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@
M+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y
M*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC
M("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI
M"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H
M)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S
M*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N
M9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]
M*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,
M;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N
M.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I
M;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*
M?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL
M92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D
M97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ
M2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I
M;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE
M?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L
M:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F
M("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM
M>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL
M92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D
M:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O
M;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD[
M"E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA
M;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB
M)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT
M*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N
M=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET
M951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B
M<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@
M;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]
M"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q
M+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T
M.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S
M=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G
M-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F
M:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A
M;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T
M>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@
M/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N
M86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C
M:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*
M)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D
M97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*
M8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN
M960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL
M93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M
M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2
M.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]
M("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%
M3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P
M;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*
M;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE
M(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M
M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N
M?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*
M)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@
M1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?
M;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^
M=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB
M97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA
M;64B*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N
M86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL
M94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I
M9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C
M:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A
M9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;
M('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T
M9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@
M*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A
M<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A
M<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL
M93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK
M<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*
M<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E
M9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER
M92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E
M($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER
M92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL
M93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I
M8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7
M:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![
M(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U
M:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E
M(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q
M=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T
M:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U0
M1$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE
M>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D
M<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I
M(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D
M*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,
M;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M
M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-
M17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@
M<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]
M<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P
M<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D
M8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU
M."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<[
M"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*
M?0IE;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?
M=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P
M.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF
M("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B
M/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D
M9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I
M;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@
M/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*
M)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W
M-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE
M('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L
M;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA
M;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@
M)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP
M;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*
M8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@
M)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK
M*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P
M<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@
M)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D
M,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD
M(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R
M;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!
M345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P
M*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N
M(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF
M;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O
M+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!]
M(&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N
M9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I
M+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92([
M"GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D
M14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T
M8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#
M=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*
M)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO
M)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?
M24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6
M>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-
M4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@
M>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!4
M14U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D
M14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/
M0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@
M,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I
M9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@
M>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F
M:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET
M7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE
M9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R
M:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005([
M"G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`
M<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R
M:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI
M"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI
M="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`
M(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI
M="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``
M`````1L#.^P````<````V(/__S@!``"8A___8`$``*B'__](!@``V(G__P@!
M``#HBO__>`$``/B@___(`0``R*'__Q0"``!8HO__0`(``*BD__^,`@``**;_
M_]@"``#(IO___`(``*BG__]``P``V*?__U@#```HJ/__<`,``/BH__^<`P``
M"*G__[`#```(J___$`0``#BK__\D!```**S__W0$```(KO__F`0``(BN__^T
M!```N*[__]`$``"8K___$`4``+B[___(!0``J+___Q0&```8P/__>`8``"C`
M__^0!@``F,#__]@&````````%``````````!>E(``7@0`1L,!PB0`0<0%```
M`!P```#(B/__*P``````````````%``````````!>E(``7@0`1L,!PB0`0``
M)````!P```"8@O__P`,````.$$8.&$H/"W<(@``_&CLJ,R0B`````!0```!$
M````,(;__P@``````````````$P```!<````:(G__PX6````0@X0CP)"#AB.
M`T8.((T$0@XHC`5$#C"&!D$..(,'1P[0!0/F%0H..$$.,$$.*$(.($(.&$(.
M$$(."$$+````2````*P````HG___S`````!"#A"/`D(.&(X#0@X@C01"#BB,
M!4$.,(8&00XX@P=$#D`";`H..$0.,$$.*$(.($(.&$(.$$(."$D+`"@```#X
M````K)___X0`````00X0A@)!#AB#`T<.,`)S"@X800X000X(00L`2````"0!
M```0H/__3`(```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=*#F`#
M)@$*#CA!#C!!#BA"#B!"#AA"#A!"#@A$"T@```!P`0``%*+__W$!````0@X0
MCP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1P[P`7X*#CA!#C!!#BA"#B!"
M#AA"#A!"#@A'"P`@````O`$``$BC__^4`````$$.$(,"4@ZP`0)3"@X000X(
M20M`````X`$``,2C___>`````$(.$(X"0@X8C0-%#B",!$$.*(8%1`XP@P93
M#L`@`H0*#C!!#BA!#B!"#AA"#A!"#@A#"Q0````D`@``8*3__S``````1`X0
M9PX(`!0````\`@``>*3__TD`````1`X0?0X(`"@```!4`@``L*3__\$`````
M00X0A@)!#AB#`T<.P$`"IPH.&$$.$$$."$8+$````(`"``!4I?__!0``````
M``!<````E`(``%"E___Z`0```$(.$(\"0@X8C@-"#B"-!$(.*(P%1`XPA@9!
M#CB#!U$.\"$"9`H..$$.,$$.*$(.($(.&$(.$$(."$0+`I8.^"%/#H`B:@[X
M(4$.\"$````0````]`(``/"F__\J`````````$P````(`P``#*?__^P`````
M2@X0A@)!#AB#`T0.('4*#AA(PPX00<8."$L+8@H.&$C##A!!Q@X(30L"0`X8
M00X000X(1L/&4`X@@P.&`@``(````%@#``"LI___VP$```!!#A"#`DL.4`-L
M`0H.$$$."$<+&````'P#``!HJ?__=`````!$#B!O"@X(10L``!@```"8`P``
MS*G__R0`````1`X06`H."$0+```\````M`,``."I___<`````$(.$(P"00X8
MA@-$#B"#!$L.,`)8#CA/#D!N#CA!#C!J"@X@00X800X00@X(00L`M````/0#
M``"`JO__%`P```!"#A"/`D(.&(X#10X@C01"#BB,!4@.,(8&00XX@P='#M"#
M`@,8`@[8@P)2#N"#`F@.V(,"0@[0@P(#$@$*#CA!#C!!#BA"#B!"#AA"#A!"
M#@A%"P-R`0[8@P)(#N"#`F$.V(,"00[0@P);#MB#`DD.X(,"0@[H@P)$#O"#
M`ET.T(,"`^L$#MB#`D(.X(,":`[8@P)!#M"#`@->`0H.V(,"0@[@@P)'"T@`
M``"L!```Z+7__^T#````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'
M1`Y0`\L""@XX00XP00XH0@X@0@X80@X00@X(10LP````^`0``(RY__]P````
M`$$.$(8"00X8@P-'#B`"5@H.&$$.$$$."$$+1`X81`X000X(+````"P%``!8
M@?__+0(```!!#A"&`D$.&(,#1`Y0`[T!"@X800X000X(00L`````%````%P%
M``"8N?__#```````````````1````'0%``"0N?__90````!"#A"/`D(.&(X#
M10X@C01"#BB,!4@.,(8&2`XX@P=-#D!R#CA!#C!!#BA"#B!"#AA"#A!"#@@`
M$````+P%``"XN?__`@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````@"$`
M``````!`(0````````````````````````````````````````$`````````
M`0`````````!`````````,L!`````````0````````#6`0````````$`````
M````X`$````````!`````````"\"`````````0````````![`P````````P`
M````````8!H````````-`````````$17````````&0````````!@JR``````
M`!L`````````"``````````:`````````&BK(```````'``````````(````
M`````/7^_V\`````F`(````````%``````````@-````````!@````````"0
M`P````````H`````````[`0````````+`````````!@`````````%0``````
M``````````````,`````````R*T@```````"`````````(@%````````%```
M```````'`````````!<`````````V!0````````'`````````$`3````````
M"`````````"8`0````````D`````````&``````````>``````````@`````
M````^___;P`````!```(`````/[__V\`````P!(```````#___]O``````(`
M````````\/__;P````#T$0```````/G__V\`````!```````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(BK(```````````````````
M`````````)8:````````IAH```````"V&@```````,8:````````UAH`````
M``#F&@```````/8:````````!AL````````6&P```````"8;````````-AL`
M``````!&&P```````%8;````````9AL```````!V&P```````(8;````````
MEAL```````"F&P```````+8;````````QAL```````#6&P```````.8;````
M````]AL````````&'````````!8<````````)AP````````V'````````$8<
M````````5AP```````!F'````````'8<````````AAP```````"6'```````
M`*8<````````MAP```````#&'````````-8<````````YAP```````#V'```
M``````8=````````%AT````````F'0```````#8=````````1AT```````!6
M'0```````&8=````````=AT```````"&'0```````)8=````````IAT`````
M``"V'0```````,8=````````UAT```````#F'0```````/8=````````!AX`
M```````6'@```````"8>````````-AX`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````BP(```````_____P````!P6@```````$=#
M0SH@*$1E8FEA;B`W+C,N,"TR,RD@-RXS+C``1T-#.B`H1&5B:6%N(#<N,RXP
M+3$S*2`W+C,N,```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N
M;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M
M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD871A
M+G)E;"YR;P`N9'EN86UI8P`N9&%T80`N8G-S`"YC;VUM96YT````````````
M````````````````````````````````````````````````````````````
M```````````````````+`````0````(`````````.`(````````X`@``````
M`!P````````````````````!````````````````````$P````<````"````
M`````%0"````````5`(````````@````````````````````!```````````
M`````````"$````'`````@````````!T`@```````'0"````````)```````
M``````````````0````````````````````T````]O__;P(`````````F`(`
M``````"8`@```````/@`````````!0`````````(````````````````````
M/@````L````"`````````)`#````````D`,```````!X"0````````8````!
M````"``````````8`````````$8````#`````@`````````(#0````````@-
M````````[`0```````````````````$```````````````````!.````____
M;P(`````````]!$```````#T$0```````,H`````````!0`````````"````
M``````(`````````6P```/[__V\"`````````,`2````````P!(```````"`
M``````````8````"````"````````````````````&H````$`````@``````
M``!`$P```````$`3````````F`$````````%``````````@`````````&```
M``````!T````!````$(`````````V!0```````#8%````````(@%````````
M!0```!<````(`````````!@`````````?@````$````&`````````&`:````
M````8!H````````7````````````````````!````````````````````'D`
M```!````!@````````"`&@```````(`:````````P`,`````````````````
M`!``````````$`````````"$`````0````8`````````0!X```````!`'@``
M``````@````````````````````(``````````@`````````C0````$````&
M`````````%`>````````4!X```````#R.```````````````````$```````
M`````````````),````!````!@````````!$5P```````$17````````"0``
M``````````````````0```````````````````"9`````0````(`````````
M4%<```````!05P```````%@_```````````````````(````````````````
M````H0````$````"`````````*B6````````J)8```````#L````````````
M````````!````````````````````*\````!`````@````````"8EP``````
M`)B7``````````8```````````````````@```````````````````"Y````
M#@````,`````````8*L@``````!@JP````````@````````````````````(
M``````````@`````````Q0````\````#`````````&BK(```````:*L`````
M```(````````````````````"``````````(`````````-$````!`````P``
M``````!PJR```````'"K````````$P```````````````````!``````````
M``````````#>````!@````,`````````B*L@``````"(JP```````$`"````
M````!@`````````(`````````!``````````B`````$````#`````````,BM
M(```````R*T````````P`@``````````````````"``````````(````````
M`.<````!`````P``````````L"````````"P````````(```````````````
M``````@```````````````````#M````"`````,`````````(+`@```````@
ML````````(@0```````````````````@````````````````````\@````$`
M```P````````````````````(+`````````Z`````````````````````0``
M```````!``````````$````#`````````````````````````%JP````````
@^P````````````````````$`````````````````````
